@@ -1,6 +1,12 @@
 import requests
 import json
 
+class UwsgiItAlarmLevel:
+    SYSTEM    = 0
+    USER      = 1
+    EXCEPTION = 2
+    TRACEBACK = 3
+    LOG       = 4
 
 class UwsgiItClient(object):
     def __init__(self, username, password, url):
@@ -14,7 +20,7 @@ class UwsgiItClient(object):
             response.uerror = False
             response.umessage = ""
         except requests.exceptions.HTTPError as e:
-            response.umessage = e.message
+            response.umessage = str(e)
             response.uerror = True
 
         return response
@@ -41,10 +47,10 @@ class UwsgiItClient(object):
         r = requests.get(uri, auth=(self.username, self.password), params=params)
         return self._parse_response(r)
 
-    def _post(self, path, data):
+    def _post(self, path, data, params):
         uri = self._build_uri(path)
         payload = json.dumps(data)
-        r = requests.post(uri, data=payload, auth=(self.username, self.password))
+        r = requests.post(uri, data=payload, params=params, auth=(self.username, self.password))
         return self._parse_response(r)
 
     def _delete(self, path, data=None):
@@ -63,8 +69,8 @@ class UwsgiItClient(object):
     def get(self, resource, params=None):
         return self._get(resource, params)
 
-    def post(self, resource, data):
-        return self._post(resource, data)
+    def post(self, resource, data, params=None):
+        return self._post(resource, data, params)
 
     def delete(self, resource, data=None):
         return self._delete(resource, data)
@@ -137,3 +143,38 @@ class UwsgiItClient(object):
 
     def domain_metric(self, domain, metric, params=None):
         return self.get(['metrics', 'domain.{}'.format(metric), domain], params)
+
+    def loopboxes(self, container=None, tags=None):
+        params = {}
+        if tags:
+            params['tags'] = ','.join(tags)
+        if container:
+            params['container'] = container
+        return self.get('loopboxes', params)
+
+    def loopbox(self, id):
+        return self.get(['loopboxes', id])
+
+    def create_loopbox(self, container, filename, mountpoint, readonly=False):
+        return self.post('loopboxes', {'container': container, 'filename': filename, 'mountpoint': mountpoint, 'ro': readonly})
+
+    def update_loopbox(self, id, data):
+        return self.post(['loopboxes', id], data)
+
+    def delete_loopbox(self, id):
+        return self.delete(['loopboxes', id])
+
+    def alarms(self, params=None):
+        return self.get('alarms', params)
+
+    def alarm(self, id):
+        return self.get(['alarms', id])
+
+    def create_alarm(self, container, message, params=None):
+        return self.post(['alarms', 'raise', container], message, params)
+
+    def create_alarm_key(self, container):
+        return self.get(['alarm_key', container])
+
+    def delete_alarm(self, id):
+        return self.delete(['alarms', id])
