@@ -18,6 +18,8 @@ class ClientTestCase(unittest.TestCase):
         self.client = UClient(username, password, url)
 
         self.container = os.environ['UWSGI_IT_CONTAINER']
+        self.loopbox = os.environ['UWSGI_IT_LOOPBOX']
+        self.alarm = os.environ['UWSGI_IT_ALARM']
 
     """
     News: curl https://kratos:deimos@foobar.com/api/news/
@@ -171,5 +173,66 @@ class ClientTestCase(unittest.TestCase):
         r = self.client.domain_metric(domain, "net.rx")
         self.assertEqual(r.uerror, False)
 
+    """
+    Loopboxes: curl https://kratos:deimos@foobar.com/api/loopboxes/
+    """
+    def test_loopboxes(self):
+        r = self.client.loopboxes()
+        loopboxes = r.json()
+        self.assertEqual(r.uerror, False)
+
+    def test_loopboxes_creation_delete(self):
+        r = self.client.create_loopbox(self.container, 'myloopbox', 'myloop')
+        created_message = r.json()['message']
+        self.assertEqual(created_message, 'Created')
+
+        r = self.client.loopboxes()
+        loopboxes = r.json()
+        loopbox_id = [x['id'] for x in loopboxes if x['container'] == int(self.container) and x['filename'] == 'myloopbox' and x['mountpoint'] == 'myloop'][0]
+
+        r = self.client.delete_loopbox(loopbox_id)
+        deleted_message = r.json()['message']
+        self.assertEqual(deleted_message, 'Ok')
+
+    def test_loopbox(self):
+        r = self.client.loopbox(self.loopbox)
+        loopbox = r.json()
+        self.assertEqual(r.uerror, False)
+
+    """
+    Alarms: curl https://kratos:deimos@foobar.com/api/alarms/
+    """
+    def test_alarms_get(self):
+        r = self.client.alarms()
+        alarms = r.json()
+        self.assertEqual(r.uerror, False)
+
+    def test_alarms_creation_delete(self):
+        params = {
+            'class': 'my-uwsgiit-py-testclass'
+        }
+        r = self.client.create_alarm(self.container, 'myalarm', params)
+        created_message = r.json()['message']
+        self.assertEqual(created_message, 'Created')
+
+        r = self.client.alarms(params)
+        alarms = r.json()
+        self.assertEqual(len(alarms), 1)
+        alarm_id = alarms[0]['id']
+
+        r = self.client.delete_alarm(alarm_id)
+        deleted_message = r.json()['message']
+        self.assertEqual(deleted_message, 'Ok')
+
+    def test_alarm(self):
+        r = self.client.alarm(self.alarm)
+        alarm = r.json()
+        self.assertEqual(r.uerror, False)
+
+    def test_create_alarm_key(self):
+        r = self.client.create_alarm_key(self.container)
+        key = r.json()
+        self.assertEqual(r.uerror, False)
+
 if __name__ == '__main__':
     unittest.main()
